@@ -15,14 +15,12 @@ def run_remote(cmd):
 def main():
     print("🔒 SSL Certificate Setup via Certbot")
 
-    subdomain = input("👉 Enter subdomain (e.g. test.uthavu): ").strip()
-    if not subdomain:
-        print("❌ Invalid input. Please provide a subdomain like test.uthavu")
-        sys.exit(1)
+    domain = input("👉 Enter main domain (e.g. uthavu.com): ").strip()
+    www_domain = input("👉 Enter www domain (e.g. www.uthavu.com): ").strip()
 
-    # Build full domains
-    domain = f"{subdomain}.com"
-    www_domain = f"www.{subdomain}.com"
+    if not domain or not www_domain:
+        print("❌ Invalid input. Please provide both domain and www domain.")
+        sys.exit(1)
 
     # Build certbot command
     cmd = f"sudo certbot --nginx -d {domain} -d {www_domain}"
